package com.sundot.airport.common.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.common.domain.BaseRead;

import java.util.List;


/**
 * 已读Service接口
 *
 * @author ruoyi
 * @date 2025-09-09
 */
public interface IBaseReadService extends IService<BaseRead> {
    /**
     * 查询已读
     *
     * @param id 已读主键
     * @return 已读
     */
    public BaseRead selectBaseReadById(Long id);

    /**
     * 查询已读列表
     *
     * @param baseRead 已读
     * @return 已读集合
     */
    public List<BaseRead> selectBaseReadList(BaseRead baseRead);

    /**
     * 新增已读
     *
     * @param baseRead 已读
     * @return 结果
     */
    public int insertBaseRead(BaseRead baseRead);

    /**
     * 修改已读
     *
     * @param baseRead 已读
     * @return 结果
     */
    public int updateBaseRead(BaseRead baseRead);

    /**
     * 批量删除已读
     *
     * @param ids 需要删除的已读主键集合
     * @return 结果
     */
    public int deleteBaseReadByIds(Long[] ids);

    /**
     * 删除已读信息
     *
     * @param id 已读主键
     * @return 结果
     */
    public int deleteBaseReadById(Long id);

    /**
     * 新增或更新已读
     *
     * @param baseRead 已读
     * @return 结果
     */
    public int insertOrUpdateBaseRead(BaseRead baseRead);

    /**
     * 查询已读列表
     *
     * @param baseReadQuery 查询条件
     * @param formIdList    表单ID列表
     * @return 已读集合
     */
    public List<BaseRead> selectBaseReadListByCondition(BaseRead baseReadQuery, List<Long> formIdList);
}
